pub struct Options {
pub read_only: bool,
pub hooks: Arc<HooksHandle>,
pub post_commit_hook: PostCommitHook,
pub skip_initial_reap: bool,
pub trim_config: Option<(Duration, Duration)>,
pub image_builder_mode: Option<SuperBlockInstance>,
pub inline_crypto_enabled: bool,
pub barriers_enabled: bool,
pub power_manager: Option<Arc<dyn PowerManager>>,
pub trim_charger_wait: Duration,
pub allow_type3_blobs: bool,
}Fields
read_only: boolTrue if the filesystem is read-only.
hooks: Arc<HooksHandle>Hooks for filesystem events (e.g. pre_commit, before_commit).
post_commit_hook: PostCommitHookA callback that runs after every transaction has been committed. This will be called whilst a lock is held which will block more transactions from being committed.
skip_initial_reap: boolIf true, don’t do an initial reap of the graveyard at mount time. This is useful for testing.
trim_config: Option<(Duration, Duration)>image_builder_mode: Option<SuperBlockInstance>inline_crypto_enabled: boolbarriers_enabled: boolpower_manager: Option<Arc<dyn PowerManager>>If set, this will be used to check for charger status before trimming.
trim_charger_wait: DurationHow long to wait after being placed on a charger before starting a trim.
allow_type3_blobs: boolIf true, allows writing Type 3 delivery blobs. NOTE: Type 3 delivery blobs are currently UNSTABLE / EXPERIMENTAL and subject to change.