Hooks

Struct Hooks 

pub struct Hooks<'a> { /* private fields */ }
Used to register test hooks for an FxFilesystem.

Implementations

Source

impl<'a> Hooks<'a>

pub fn new() -> (Self, Arc<HooksHandle>)

Creates a new Hooks instance and an associated HooksHandle.

pub fn set_pre_commit( &mut self, hook: impl Fn(&Transaction<'_>) -> Result<(), Error> + Send + Sync + 'a, )

Sets the hook executed before committing a transaction. This hook is called before any locks required for the commit are taken, so it’s before any transaction locks are upgraded to write locks, before any guards that are taken by calling prepare_commit for objects involved in the transaction, and before the commit mutex is acquired.

pub fn set_before_commit(&mut self, hook: impl Fn() + Send + Sync + 'a)

Sets the hook executed before a transaction starts committing. This hook is called after calling prepare_commit on all objects involved in the transaction (which might acquire some locks/guards), but before acquiring the commit mutex.

pub fn set_unlock_resources_acquired( &mut self, hook: impl Fn() + Send + Sync + 'a, )

Sets the hook executed when resources are acquired during unlock. This is called after acquiring all the keys that might be required from the crypt service.