ObjectCachePlaceholder

Trait ObjectCachePlaceholder 

pub trait ObjectCachePlaceholder<V: Value>: Send + Sync {
    // Required method
    fn complete(self: Box<Self>, value: Option<&V>);
}

Required Methods

fn complete(self: Box<Self>, value: Option<&V>)

Consumes itself in delivering the cache value for which the placeholder was reserved. Passing None for value should not be inserted into the cache, but interpreted as an incomplete search.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors