layer_from_handle

Function layer_from_handle 

pub async fn layer_from_handle<K: Key, V: LayerValue>(
    handle: DataObjectHandle<ObjectStore>,
    unwrapped_key: Option<UnwrappedKey>,
) -> Result<Arc<dyn Layer<K, V>>, Error>
Opens a persistent layer from a newly created or existing DataObjectHandle.

If the layer is encrypted and the platform uses a pager, unwrapped_key is registered with the pager and dropped immediately.