open_layers

Function open_layers 

pub async fn open_layers<K: Key, V: LayerValue>(
    store: &Arc<ObjectStore>,
    object_ids: impl IntoIterator<Item = u64>,
    crypt: Option<Arc<dyn Crypt>>,
) -> Result<(Vec<Arc<dyn Layer<K, V>>>, u64), Error>
Opens persistent layers for object_ids from store.

Returns (layers, total_size) where layers is the vector of opened Layer trait objects and total_size is the sum of the sizes in bytes of all opened layer objects.