SkipListLayer

Struct SkipListLayer 

pub struct SkipListLayer<K, V> { /* private fields */ }

Implementations

Source

impl<K, V> SkipListLayer<K, V>

pub fn new(max_item_count: usize) -> Arc<SkipListLayer<K, V>>

pub fn len(&self) -> usize

Source

impl<K: Eq + Key + OrdLowerBound, V: LayerValue> SkipListLayer<K, V>

pub fn erase(&self, key: &K)
where K: Eq,

pub fn insert(&self, item: Item<K, V>) -> Result<(), Error>

Inserts the given item.

pub fn replace_or_insert(&self, item: Item<K, V>)

Replaces or inserts the given item.

pub fn merge_into( &self, item: Item<K, V>, lower_bound: &K, merge_fn: MergeFn<K, V>, )

Merges the item into the layer.

Source

impl<K: OrdUpperBound, V> SkipListLayer<K, V>

pub fn seek<'a>(&'a self, bound: Bound<&K>) -> SkipListLayerIter<'a, K, V>

Searches for a key. Bound::Excluded is not supported. Bound::Unbounded positions the iterator on the first item in the layer.

This is an inherent version of the Layer::seek trait method which avoids returning a boxed future and boxed iterator.