pub struct SkipListLayerIter<'a, K, V> { /* private fields */ }Trait Implementations
Sourceimpl<K, V> Drop for SkipListLayerIter<'_, K, V>
impl<K, V> Drop for SkipListLayerIter<'_, K, V>
Sourceimpl<K: Key, V: LayerValue> LayerIterator<K, V> for SkipListLayerIter<'_, K, V>
impl<K: Key, V: LayerValue> LayerIterator<K, V> for SkipListLayerIter<'_, K, V>
Sourceasync fn advance(&mut self) -> Result<(), Error>
async fn advance(&mut self) -> Result<(), Error>
Advances the iterator (static dispatch, unboxed future).
Sourcefn advance_dyn<'a>(
&'a mut self,
) -> Result<Option<BoxFuture<'a, Result<(), Error>>>, Error>
fn advance_dyn<'a>( &'a mut self, ) -> Result<Option<BoxFuture<'a, Result<(), Error>>>, Error>
Advances the iterator for dynamic dispatch (trait objects).
If the iterator advances synchronously, returns
Ok(None).Sourcefn get(&self) -> Option<ItemRef<'_, K, V>>
fn get(&self) -> Option<ItemRef<'_, K, V>>
Returns the current item. This will be None if called when the iterator is first crated i.e.
before either seek or advance has been called, and None if the iterator has reached the end
of the layer.
impl<K, V> Send for SkipListLayerIter<'_, K, V>
impl<K, V> Sync for SkipListLayerIter<'_, K, V>