pub enum MaybeContainsKey {
False,
Maybe,
RangeKeyTooLarge,
}Variants
False
The layer definitely does not contain records relevant to the key.
Maybe
The layer might contain records relevant to the key.
RangeKeyTooLarge
The range key was too large to check against the existence filter, so the check was skipped.