pub type BoxedLayerIterator<'iter, K, V> = Box<dyn LayerIterator<K, V> + 'iter>;Aliased Type
pub struct BoxedLayerIterator<'iter, K, V>(/* private fields */);Trait Implementations
Sourceimpl<'iter, K, V> LayerIterator<K, V> for BoxedLayerIterator<'iter, K, V>
impl<'iter, K, V> LayerIterator<K, V> for BoxedLayerIterator<'iter, K, V>
Sourceasync fn advance(&mut self) -> Result<(), Error>
async fn advance(&mut self) -> Result<(), Error>
Advances the iterator (static dispatch, unboxed future).
Sourcefn advance_dyn<'a>(
&'a mut self,
) -> Result<Option<BoxFuture<'a, Result<(), Error>>>, Error>
fn advance_dyn<'a>( &'a mut self, ) -> Result<Option<BoxFuture<'a, Result<(), Error>>>, Error>
Advances the iterator for dynamic dispatch (trait objects).
If the iterator advances synchronously, returns
Ok(None).Sourcefn get(&self) -> Option<ItemRef<'_, K, V>>
fn get(&self) -> Option<ItemRef<'_, K, V>>
Returns the current item. This will be None if called when the iterator is first crated i.e.
before either seek or advance has been called, and None if the iterator has reached the end
of the layer.