pub struct DurationMeasureScope<'a> { /* private fields */ }Expand description
A scope that measures the duration of an operation and records it in a DurationMeasure.
When the scope is dropped, the duration is added to the histogram and the cumulative time is
incremented.
Implementations
Sourceimpl<'a> DurationMeasureScope<'a>
impl<'a> DurationMeasureScope<'a>
pub fn new(measure: &'a DurationMeasure) -> Self