ReadObjectHandle

Trait ReadObjectHandle 

pub trait ReadObjectHandle: ObjectHandle {
    // Required methods
    fn read_aligned<'life0, 'life1, 'async_trait>(
        &'life0 self,
        offset: u64,
        buf: MutableBufferRef<'life1>,
    ) -> Pin<Box<dyn Future<Output = Result<usize, Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn get_size(&self) -> u64;
}

Required Methods

fn read_aligned<'life0, 'life1, 'async_trait>( &'life0 self, offset: u64, buf: MutableBufferRef<'life1>, ) -> Pin<Box<dyn Future<Output = Result<usize, Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Fills buf with bytes read from offset on the underlying device.

Both offset and buf.len() must be aligned to the object’s block_size().

Returns the number of bytes read. If offset >= size, returns 0. Holes/sparse extents within the read range are zero-filled. Callers should not make any assumptions about the contents of the buffer past the returned read amount.

fn get_size(&self) -> u64

Returns the size of the object.