replace_child_with_purge

Function replace_child_with_purge 

pub async fn replace_child_with_purge<'a, S: HandleOwner>(
    transaction: &mut Transaction<'a>,
    src: Option<(&'a Directory<S>, &str)>,
    dst: (&'a Directory<S>, &str),
    can_purge: bool,
) -> Result<ReplacedChild, Error>
Like replace_child, but if can_purge is true and the replaced child is a file or symlink with no remaining references, it will attempt to purge the object directly in the current transaction, skipping the graveyard.