Extent

Struct Extent 

pub struct Extent(pub Range<u64>);
Extent represents a physical or logical range of bytes, aligned to a 512-byte boundary.

Tuple Fields

0: Range<u64>

Implementations

Source

impl Extent

pub fn overlap(&self, other: &Extent) -> Option<Range<u64>>

Returns the range of bytes common between this extent and |other|.

pub fn search_key(&self) -> Self

Returns the search key for this extent; that is, a key which is <= this key under Ord and OrdLowerBound. This would be used when searching for an extent with |find| (when we want to find any overlapping extent, which could include extents that start earlier). For example, if the tree has extents 50..150 and 150..200 and we wish to read 100..200, we’d search for 0..101 which would set the iterator to 50..150.

pub fn search_key_from_offset(offset: u64) -> Self

Similar to previous, but from an offset. Returns a search key that will find the first extent that touches offset..

pub fn key_for_merge_into(&self) -> Self

Returns the merge key for this extent; that is, a key which is <= this extent and any other possibly overlapping extent, under Ord. This would be used to set the hint for |merge_into|.

For example, if the tree has extents 0..50, 50..150 and 150..200 and we wish to insert 100..150, we’d use a merge hint of 0..100 which would set the iterator to 50..150 (the first element > 100..150 under Ord).

pub fn fuzzy_hash_partition(&self) -> ExtentPartitionIterator

Returns an iterator over the Extent partitions which overlap this key (see FuzzyHash).

Methods from Deref<Target = Range<u64>>

1.35.0 · Source

pub fn contains<U>(&self, item: &U) -> bool
where Idx: PartialOrd<U>, U: PartialOrd<Idx> + ?Sized,

Returns true if item is contained in the range.

Examples
assert!(!(3..5).contains(&2));
assert!( (3..5).contains(&3));
assert!( (3..5).contains(&4));
assert!(!(3..5).contains(&5));

assert!(!(3..3).contains(&3));
assert!(!(3..2).contains(&3));

assert!( (0.0..1.0).contains(&0.5));
assert!(!(0.0..1.0).contains(&f32::NAN));
assert!(!(0.0..f32::NAN).contains(&0.5));
assert!(!(f32::NAN..1.0).contains(&0.5));
1.47.0 · Source

pub fn is_empty(&self) -> bool
where Idx: PartialOrd,

Returns true if the range contains no items.

Examples
assert!(!(3..5).is_empty());
assert!( (3..3).is_empty());
assert!( (3..2).is_empty());

The range is empty if either side is incomparable:

assert!(!(3.0..5.0).is_empty());
assert!( (3.0..f32::NAN).is_empty());
assert!( (f32::NAN..5.0).is_empty());