pub struct ReservationUpdate(/* private fields */);Expand description
ReservationUpdate is an associated object that sets the amount reserved for an object (overwriting any previous amount). Updates must be applied as part of a transaction before did_commit_transaction runs because it will reconcile the accounting for reserved metadata space.
Implementations