pub enum ObjectKeyDataV54 {
Object,
Keys,
Attribute(u64, AttributeKeyV32),
Child {
name: String,
},
GraveyardEntry {
object_id: u64,
},
Project {
project_id: u64,
property: ProjectPropertyV32,
},
ExtendedAttribute {
name: Vec<u8>,
},
GraveyardAttributeEntry {
object_id: u64,
attribute_id: u64,
},
EncryptedCasefoldChild(EncryptedCasefoldChild),
LegacyCasefoldChild(CasefoldString),
EncryptedChild(EncryptedChild),
CasefoldChild {
hash_code: u32,
name: String,
},
}Variants
Object
A generic, untyped object. This must come first and sort before all other keys for a given object because it’s also used as a tombstone and it needs to merge with all following keys.
Keys
Encryption keys for an object.
Attribute(u64, AttributeKeyV32)
An attribute associated with an object. It has a 64-bit ID.
Child
A child of a directory.
GraveyardEntry
A graveyard entry for an entire object.
Project
Project ID info. This should only be attached to the volume’s root node. Used to address the
configured limit and the usage tracking which are ordered after the project_id to provide
locality of the two related values.
ExtendedAttribute
An extended attribute associated with an object. It stores the name used for the extended attribute, which has a maximum size of 255 bytes enforced by fuchsia.io.
GraveyardAttributeEntry
A graveyard entry for an attribute.
EncryptedCasefoldChild(EncryptedCasefoldChild)
A child of an encrypted directory. We store the filename in its encrypted form. hash_code
is the hash of the casefolded human-readable name if a directory is also casefolded. In
some legacy cases, this is also used in non-casefolded cases, and in some of those cases the
hash code can be 0. Going forward, these cases are covered by EncryptedChild below.
LegacyCasefoldChild(CasefoldString)
Case-insensitive child (legacy).
EncryptedChild(EncryptedChild)
An encrypted child that does not use case folding.
CasefoldChild
A child of a directory that uses the casefold feature. (i.e. case insensitive, case preserving names)