pub enum ObjectKindV49 {
File {
refs: u64,
},
Directory {
sub_dirs: u64,
wrapping_key_id: Option<WrappingKeyId>,
casefold: bool,
},
Graveyard,
Symlink {
refs: u64,
link: Box<[u8]>,
},
EncryptedSymlink {
refs: u64,
link: Box<[u8]>,
},
}Variants
File
Directory
Fields

wrapping_key_id: Option<WrappingKeyId>If set, contains the wrapping key id used to encrypt the file contents and filenames in this directory.
Graveyard
Symlink
Fields
EncryptedSymlink
Fields