pub enum ObjectValueV54 {
None,
Some,
Object {
kind: ObjectKindV54,
attributes: ObjectAttributesV49,
},
Keys(EncryptionKeysV49),
Attribute {
size: u64,
has_overwrite_extents: bool,
},
Extent(ExtentValueV38),
Child(ChildValue),
Trim,
BytesAndNodes {
bytes: i64,
nodes: i64,
},
ExtendedAttribute(ExtendedAttributeValueV32),
VerifiedAttribute {
size: u64,
fsverity_metadata: FsverityMetadataV50,
},
}Variants
None
Some keys have no value (this often indicates a tombstone of some sort). Records with this value are always filtered when a major compaction is performed, so the meaning must be the same as if the item was not present.
Some
Some keys have no value but need to differentiate between a present value and no value (None) i.e. their value is really a boolean: None => false, Some => true.
Object
The value for an ObjectKey::Object record.
Keys(EncryptionKeysV49)
Specifies encryption keys to use for an object.
Attribute
An attribute associated with a file object. |size| is the size of the attribute in bytes.
Extent(ExtentValueV38)
An extent associated with an object.
Child(ChildValue)
A child of an object.
Trim
Graveyard entries can contain these entries which will cause a file that has extents beyond EOF to be trimmed at mount time. This is used in cases where shrinking a file can exceed the bounds of a single transaction.
BytesAndNodes
Added to support tracking Project ID usage and limits.
ExtendedAttribute(ExtendedAttributeValueV32)
A value for an extended attribute. Either inline or a redirection to an attribute with extents.
VerifiedAttribute
An attribute associated with a verified file object. |size| is the size of the attribute in bytes.
Implementations
Sourceimpl ObjectValueV54
impl ObjectValueV54
Sourcepub fn file(
refs: u64,
allocated_size: u64,
creation_time: Timestamp,
modification_time: Timestamp,
access_time: Timestamp,
change_time: Timestamp,
project_id: u64,
posix_attributes: Option<PosixAttributes>,
) -> ObjectValue
pub fn file( refs: u64, allocated_size: u64, creation_time: Timestamp, modification_time: Timestamp, access_time: Timestamp, change_time: Timestamp, project_id: u64, posix_attributes: Option<PosixAttributes>, ) -> ObjectValue
Creates an ObjectValue for a file object.
pub fn keys(encryption_keys: EncryptionKeys) -> ObjectValue
Sourcepub fn attribute(size: u64, has_overwrite_extents: bool) -> ObjectValue
pub fn attribute(size: u64, has_overwrite_extents: bool) -> ObjectValue
Creates an ObjectValue for an object attribute.
Sourcepub fn verified_attribute(
size: u64,
fsverity_metadata: FsverityMetadata,
) -> ObjectValue
pub fn verified_attribute( size: u64, fsverity_metadata: FsverityMetadata, ) -> ObjectValue
Creates an ObjectValue for an object attribute of a verified file.
Sourcepub fn extent(device_offset: u64, key_id: u64) -> ObjectValue
pub fn extent(device_offset: u64, key_id: u64) -> ObjectValue
Creates an ObjectValue for an insertion/replacement of an object extent.
Sourcepub fn extent_with_checksum(
device_offset: u64,
checksum: Checksums,
key_id: u64,
) -> ObjectValue
pub fn extent_with_checksum( device_offset: u64, checksum: Checksums, key_id: u64, ) -> ObjectValue
Creates an ObjectValue for an insertion/replacement of an object extent.
Sourcepub fn deleted_extent() -> ObjectValue
pub fn deleted_extent() -> ObjectValue
Creates an ObjectValue for a deletion of an object extent.
Sourcepub fn child(object_id: u64, object_descriptor: ObjectDescriptor) -> ObjectValue
pub fn child(object_id: u64, object_descriptor: ObjectDescriptor) -> ObjectValue
Creates an ObjectValue for an object child.
Sourcepub fn symlink(
link: impl Into<Box<[u8]>>,
creation_time: Timestamp,
modification_time: Timestamp,
project_id: u64,
) -> ObjectValue
pub fn symlink( link: impl Into<Box<[u8]>>, creation_time: Timestamp, modification_time: Timestamp, project_id: u64, ) -> ObjectValue
Creates an ObjectValue for an object symlink.
Sourcepub fn encrypted_symlink(
link: impl Into<Box<[u8]>>,
creation_time: Timestamp,
modification_time: Timestamp,
project_id: u64,
) -> ObjectValue
pub fn encrypted_symlink( link: impl Into<Box<[u8]>>, creation_time: Timestamp, modification_time: Timestamp, project_id: u64, ) -> ObjectValue
Creates an ObjectValue for an encrypted symlink object.
pub fn inline_extended_attribute(value: impl Into<Vec<u8>>) -> ObjectValue
pub fn extended_attribute(attribute_id: u64) -> ObjectValue