AttributeId

Struct AttributeId 

#[repr(transparent)]
pub struct AttributeId(pub u64);

Tuple Fields

0: u64

Implementations

Source

impl AttributeId

pub const DATA: Self

The common case for extents which cover the data payload of an object.

pub const BLOB_METADATA: Self

Contains a serialized and versioned BlobMetadata struct. Use [BlobMetadata::read_from] and [BlobMetadata::write_to] to access this attribute.

pub const BLOB_MERKLE: Self

Contains a serialized BlobMetadataUnversioned struct. This attribute may still exist on blobs but should no longer be written. Use AttributeId::BLOB_METADATA instead.

pub const FSVERITY_MERKLE: Self

For fsverity files in Fxfs, we store the merkle tree of the verified file at a well-known attribute.

pub const XATTR_RANGE_START: Self

The range of fxfs attribute IDs which are reserved for extended attribute values. Whenever a new attribute is needed, the first unused ID will be chosen from this range. It’s technically safe to change these values, but it has potential consequences - they are only used during ID selection, so any existing extended attributes keep their IDs, which means any past or present selected range here could potentially have used attributes unless they are explicitly migrated, which isn’t currently done.

pub const XATTR_RANGE_END: Self

pub const SORTED_START: Self

A semantic alias for the 0 attribute ID, indicating that it is being used as a starting point to iterate over all attributes rather than specifically looking up the primary data attribute AttributeId::DATA.

pub const fn raw(self) -> u64

pub const fn next(self) -> Self

Returns the current id + 1.

pub const fn is_xattr(self) -> bool

Returns true if the attribute ID is within the range of extended attributes.