pub struct FsverityMetadataV33 {
pub root_digest: RootDigestV33,
pub salt: Vec<u8>,
}Fields
root_digest: RootDigestV33salt: Vec<u8>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FsverityMetadataV33
impl<'de> Deserialize<'de> for FsverityMetadataV33
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<FsverityMetadataV33> for FsverityMetadataV50
impl From<FsverityMetadataV33> for FsverityMetadataV50
Sourcefn from(value: FsverityMetadataV33) -> Self
fn from(value: FsverityMetadataV33) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for FsverityMetadataV33
impl Serialize for FsverityMetadataV33
Sourceimpl TypeFingerprint for FsverityMetadataV33
impl TypeFingerprint for FsverityMetadataV33
fn fingerprint() -> String
Sourceimpl Versioned for FsverityMetadataV33
impl Versioned for FsverityMetadataV33
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>