pub struct ObjectKeyV40 {
pub object_id: u64,
pub data: ObjectKeyDataV40,
}Fields
object_id: u64data: ObjectKeyDataV40Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ObjectKeyV40
impl<'de> Deserialize<'de> for ObjectKeyV40
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ObjectKeyV40> for ObjectKeyV43
impl From<ObjectKeyV40> for ObjectKeyV43
Sourcefn from(from: ObjectKeyV40) -> Self
fn from(from: ObjectKeyV40) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for ObjectKeyV40
impl Serialize for ObjectKeyV40
Sourceimpl TypeFingerprint for ObjectKeyV40
impl TypeFingerprint for ObjectKeyV40
fn fingerprint() -> String
Sourceimpl Versioned for ObjectKeyV40
impl Versioned for ObjectKeyV40
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>