pub struct ObjectKeyV43 {
pub object_id: u64,
pub data: ObjectKeyDataV43,
}Fields
object_id: u64data: ObjectKeyDataV43Trait Implementations
Sourceimpl Clone for ObjectKeyV43
impl Clone for ObjectKeyV43
Sourcefn clone(&self) -> ObjectKeyV43
fn clone(&self) -> ObjectKeyV43
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjectKeyV43
impl Debug for ObjectKeyV43
Sourceimpl<'de> Deserialize<'de> for ObjectKeyV43
impl<'de> Deserialize<'de> for ObjectKeyV43
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ObjectKeyV40> for ObjectKeyV43
impl From<ObjectKeyV40> for ObjectKeyV43
Sourcefn from(from: ObjectKeyV40) -> Self
fn from(from: ObjectKeyV40) -> Self
Converts to this type from the input type.
Sourceimpl From<ObjectKeyV43> for ObjectKeyV54
impl From<ObjectKeyV43> for ObjectKeyV54
Sourcefn from(from: ObjectKeyV43) -> Self
fn from(from: ObjectKeyV43) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ObjectKeyV43
impl Hash for ObjectKeyV43
Sourceimpl Ord for ObjectKeyV43
impl Ord for ObjectKeyV43
Sourcefn cmp(&self, other: &ObjectKeyV43) -> Ordering
fn cmp(&self, other: &ObjectKeyV43) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ObjectKeyV43
impl PartialEq for ObjectKeyV43
Sourceimpl PartialOrd for ObjectKeyV43
impl PartialOrd for ObjectKeyV43
Sourceimpl Serialize for ObjectKeyV43
impl Serialize for ObjectKeyV43
Sourceimpl TypeFingerprint for ObjectKeyV43
impl TypeFingerprint for ObjectKeyV43
fn fingerprint() -> String
Sourceimpl Versioned for ObjectKeyV43
impl Versioned for ObjectKeyV43
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>
impl Eq for ObjectKeyV43
impl StructuralPartialEq for ObjectKeyV43