pub struct EncryptedTransactionV59(pub Vec<MutationV59>);Tuple Fields
0: Vec<MutationV59>Trait Implementations
Sourceimpl Clone for EncryptedTransactionV59
impl Clone for EncryptedTransactionV59
Sourcefn clone(&self) -> EncryptedTransactionV59
fn clone(&self) -> EncryptedTransactionV59
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncryptedTransactionV59
impl Debug for EncryptedTransactionV59
Sourceimpl<'de> Deserialize<'de> for EncryptedTransactionV59
impl<'de> Deserialize<'de> for EncryptedTransactionV59
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EncryptedTransactionV59
Sourceimpl From<EncryptedTransactionV57> for EncryptedTransactionV59
impl From<EncryptedTransactionV57> for EncryptedTransactionV59
Sourcefn from(old: EncryptedTransactionV57) -> Self
fn from(old: EncryptedTransactionV57) -> Self
Converts to this type from the input type.
Sourceimpl Ord for EncryptedTransactionV59
impl Ord for EncryptedTransactionV59
Sourcefn cmp(&self, other: &EncryptedTransactionV59) -> Ordering
fn cmp(&self, other: &EncryptedTransactionV59) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for EncryptedTransactionV59
impl PartialEq for EncryptedTransactionV59
Sourceimpl PartialOrd for EncryptedTransactionV59
impl PartialOrd for EncryptedTransactionV59
Sourceimpl Serialize for EncryptedTransactionV59
impl Serialize for EncryptedTransactionV59
impl StructuralPartialEq for EncryptedTransactionV59
Sourceimpl TypeFingerprint for EncryptedTransactionV59
impl TypeFingerprint for EncryptedTransactionV59
fn fingerprint() -> String
Sourceimpl Versioned for EncryptedTransactionV59
impl Versioned for EncryptedTransactionV59
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>
Sourceimpl VersionedLatest for EncryptedTransactionV59
impl VersionedLatest for EncryptedTransactionV59
Sourcefn deserialize_from_version<R>(reader: &mut R, version: Version) -> Result<Self>
fn deserialize_from_version<R>(reader: &mut R, version: Version) -> Result<Self>
Deserializes from a given version format and upgrades to the latest version.