pub struct ObjectEncryptionOptions {
pub permanent: bool,
pub key_id: u64,
pub key: EncryptionKey,
pub unwrapped_key: UnwrappedKey,
}Expand description
Parameters for encrypting a newly created object.
Fields
permanent: boolIf set, the keys are treated as permanent and never evicted from the KeyManager cache.
This is necessary when keys are managed by another store; for example, the layer files
of a child store are objects in the root store, but they are encrypted with keys from the
child store. Generally, most objects should have this set to false.
key_id: u64key: EncryptionKeyunwrapped_key: UnwrappedKeyAuto Trait Implementations
impl Freeze for ObjectEncryptionOptions
impl RefUnwindSafe for ObjectEncryptionOptions
impl Send for ObjectEncryptionOptions
impl Sync for ObjectEncryptionOptions
impl Unpin for ObjectEncryptionOptions
impl UnsafeUnpin for ObjectEncryptionOptions
impl UnwindSafe for ObjectEncryptionOptions