pub struct StoreInfoV49 { /* private fields */ }Trait Implementations
Sourceimpl Default for StoreInfoV49
impl Default for StoreInfoV49
Sourcefn default() -> StoreInfoV49
fn default() -> StoreInfoV49
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StoreInfoV49
impl<'de> Deserialize<'de> for StoreInfoV49
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<StoreInfoV40> for StoreInfoV49
impl From<StoreInfoV40> for StoreInfoV49
Sourcefn from(from: StoreInfoV40) -> Self
fn from(from: StoreInfoV40) -> Self
Converts to this type from the input type.
Sourceimpl From<StoreInfoV49> for StoreInfoV52
impl From<StoreInfoV49> for StoreInfoV52
Sourcefn from(value: StoreInfoV49) -> Self
fn from(value: StoreInfoV49) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for StoreInfoV49
impl Serialize for StoreInfoV49
Sourceimpl TypeFingerprint for StoreInfoV49
impl TypeFingerprint for StoreInfoV49
fn fingerprint() -> String
Sourceimpl Versioned for StoreInfoV49
impl Versioned for StoreInfoV49
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>