MetadataReservation

Enum MetadataReservation 

pub enum MetadataReservation<'a> {
    BorrowedMetadata,
    BorrowedMetadataAndData,
    Reservation(Reservation),
    Hold(Hold<'a>),
}

Variants



BorrowedMetadata

Metadata space for this transaction is being borrowed from ObjectManager’s metadata reservation, but allocations/deallocations in the transaction do not use it.



BorrowedMetadataAndData

Metadata space for this transaction is being borrowed from ObjectManager’s metadata reservation, and allocations/deallocations in the transaction also use ObjectManager’s metadata reservation.



Reservation(Reservation)

A metadata reservation was made when the transaction was created.



Hold(Hold<'a>)

The metadata space is being held within an existing reservation.