pub enum MutationV57 {
ObjectStore(ObjectStoreMutationV56),
EncryptedObjectStore(Box<[u8]>),
Allocator(AllocatorMutationV32),
BeginFlush,
EndFlush,
DeleteVolume,
UpdateBorrowed(u64),
UpdateMutationsKey(UpdateMutationsKey),
CreateInternalDir(u64),
}Variants
ObjectStore(ObjectStoreMutationV56)
EncryptedObjectStore(Box<[u8]>)
Allocator(AllocatorMutationV32)
BeginFlush
Indicates the beginning of a flush. This would typically involve sealing a tree.
EndFlush
Indicates the end of a flush. This would typically involve replacing the immutable layers with compacted ones.
DeleteVolume
Volume has been deleted. Requires we remove it from the set of managed ObjectStore.
UpdateBorrowed(u64)
UpdateMutationsKey(UpdateMutationsKey)
CreateInternalDir(u64)
Implementations
Sourceimpl MutationV57
impl MutationV57
pub fn insert_object(key: ObjectKey, value: ObjectValue) -> Self
pub fn replace_or_insert_object(key: ObjectKey, value: ObjectValue) -> Self
pub fn merge_object(key: ObjectKey, value: ObjectValue) -> Self
pub fn update_mutations_key(key: FxfsKey) -> Self