pub struct ObjectStoreMutationV50 {
pub item: ObjectItemV50,
pub op: OperationV32,
}Fields
item: ObjectItemV50op: OperationV32Trait Implementations
Sourceimpl Clone for ObjectStoreMutationV50
impl Clone for ObjectStoreMutationV50
Sourcefn clone(&self) -> ObjectStoreMutationV50
fn clone(&self) -> ObjectStoreMutationV50
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjectStoreMutationV50
impl Debug for ObjectStoreMutationV50
Sourceimpl<'de> Deserialize<'de> for ObjectStoreMutationV50
impl<'de> Deserialize<'de> for ObjectStoreMutationV50
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ObjectStoreMutationV49> for ObjectStoreMutationV50
impl From<ObjectStoreMutationV49> for ObjectStoreMutationV50
Sourcefn from(from: ObjectStoreMutationV49) -> Self
fn from(from: ObjectStoreMutationV49) -> Self
Converts to this type from the input type.
Sourceimpl From<ObjectStoreMutationV50> for ObjectStoreMutationV54
impl From<ObjectStoreMutationV50> for ObjectStoreMutationV54
Sourcefn from(from: ObjectStoreMutationV50) -> Self
fn from(from: ObjectStoreMutationV50) -> Self
Converts to this type from the input type.
Sourceimpl Ord for ObjectStoreMutationV50
impl Ord for ObjectStoreMutationV50
Sourceimpl PartialEq for ObjectStoreMutationV50
impl PartialEq for ObjectStoreMutationV50
Sourceimpl PartialOrd for ObjectStoreMutationV50
impl PartialOrd for ObjectStoreMutationV50
Sourceimpl Serialize for ObjectStoreMutationV50
impl Serialize for ObjectStoreMutationV50
Sourceimpl TypeFingerprint for ObjectStoreMutationV50
impl TypeFingerprint for ObjectStoreMutationV50
fn fingerprint() -> String
Sourceimpl Versioned for ObjectStoreMutationV50
impl Versioned for ObjectStoreMutationV50
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>
impl Eq for ObjectStoreMutationV50