pub struct ObjectStoreMutationV54 {
pub item: ObjectItemV54,
pub op: Operation,
}Fields
item: ObjectItemV54op: OperationTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ObjectStoreMutationV54
impl<'de> Deserialize<'de> for ObjectStoreMutationV54
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ObjectStoreMutationV50> for ObjectStoreMutationV54
impl From<ObjectStoreMutationV50> for ObjectStoreMutationV54
Sourcefn from(from: ObjectStoreMutationV50) -> Self
fn from(from: ObjectStoreMutationV50) -> Self
Converts to this type from the input type.
Sourceimpl From<ObjectStoreMutationV54> for ObjectStoreMutationV55
impl From<ObjectStoreMutationV54> for ObjectStoreMutationV55
Sourcefn from(from: ObjectStoreMutationV54) -> Self
fn from(from: ObjectStoreMutationV54) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for ObjectStoreMutationV54
impl Serialize for ObjectStoreMutationV54
Sourceimpl TypeFingerprint for ObjectStoreMutationV54
impl TypeFingerprint for ObjectStoreMutationV54
fn fingerprint() -> String
Sourceimpl Versioned for ObjectStoreMutationV54
impl Versioned for ObjectStoreMutationV54
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>