pub struct ObjectStoreMutationV55 {
pub item: ObjectItemV55,
pub op: Operation,
}Fields
item: ObjectItemV55op: OperationTrait Implementations
Sourceimpl Clone for ObjectStoreMutationV55
impl Clone for ObjectStoreMutationV55
Sourcefn clone(&self) -> ObjectStoreMutationV55
fn clone(&self) -> ObjectStoreMutationV55
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjectStoreMutationV55
impl Debug for ObjectStoreMutationV55
Sourceimpl<'de> Deserialize<'de> for ObjectStoreMutationV55
impl<'de> Deserialize<'de> for ObjectStoreMutationV55
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ObjectStoreMutationV54> for ObjectStoreMutationV55
impl From<ObjectStoreMutationV54> for ObjectStoreMutationV55
Sourcefn from(from: ObjectStoreMutationV54) -> Self
fn from(from: ObjectStoreMutationV54) -> Self
Converts to this type from the input type.
Sourceimpl From<ObjectStoreMutationV55> for ObjectStoreMutationV56
impl From<ObjectStoreMutationV55> for ObjectStoreMutationV56
Sourcefn from(from: ObjectStoreMutationV55) -> Self
fn from(from: ObjectStoreMutationV55) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ObjectStoreMutationV55
impl PartialEq for ObjectStoreMutationV55
Sourcefn eq(&self, other: &ObjectStoreMutationV55) -> bool
fn eq(&self, other: &ObjectStoreMutationV55) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObjectStoreMutationV55
impl Serialize for ObjectStoreMutationV55
impl StructuralPartialEq for ObjectStoreMutationV55
Sourceimpl TypeFingerprint for ObjectStoreMutationV55
impl TypeFingerprint for ObjectStoreMutationV55
fn fingerprint() -> String
Sourceimpl Versioned for ObjectStoreMutationV55
impl Versioned for ObjectStoreMutationV55
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>