pub struct Options<'a> {
pub skip_journal_checks: bool,
pub reservation: ReservationOptions<'a>,
pub parent_transaction: Option<&'a Transaction<'a>>,
}Expand description
This allows for special handling of certain transactions such as deletes and the
extension of Journal extents. For most other use cases it is appropriate to use
default() here.
Fields
skip_journal_checks: boolIf true, don’t check for low journal space. This should be true for any transactions that might alleviate journal space (i.e. compaction).
reservation: ReservationOptions<'a>How metadata and allocator reservations should be handled for the transaction.
parent_transaction: Option<&'a Transaction<'a>>If set, indicates that this transaction is nested within parent_transaction and shares
its in-flight transaction slot. The use case for this is a nested transaction, where a
separate transaction must be committed while constructing another transaction (for example,
when rolling the object ID cipher).
NOTE: The locks acquired by the nested transaction do not cooperate in any way with the locks already held by parent_transaction, so care must still be taken to avoid deadlocks.