pub trait AssociatedObject: Send + Sync {
// Provided method
fn will_apply_mutation(
&self,
_mutation: &Mutation,
_object_id: u64,
_manager: &ObjectManager,
) { ... }
}Expand description
Mutations in a transaction can be associated with an object so that when mutations are applied, updates can be applied to in-memory structures. For example, we cache object sizes, so when a size change is applied, we can update the cached object size.
Provided Methods
fn will_apply_mutation( &self, _mutation: &Mutation, _object_id: u64, _manager: &ObjectManager, )
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".