pub type EncryptedMutations = EncryptedMutationsV49;Aliased Type
pub struct EncryptedMutations { /* private fields */ }Trait Implementations
Sourceimpl Debug for EncryptedMutations
impl Debug for EncryptedMutations
Sourceimpl Versioned for EncryptedMutations
impl Versioned for EncryptedMutations
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.