compare_keys

Function compare_keys 

pub fn compare_keys(a: &[u8], b: &[u8]) -> Result<Ordering, Error>
Evaluates comparison ordering between two serialized keys located at the beginning of a and b.

Both byte slices must start with chunked key data. If the serialized key is <= 254 bytes, it is prefixed by a 1-byte length. If 255 bytes or longer (>= 255 bytes), it is serialized as a sequence of 255-byte chunks. Any trailing bytes after each serialized key are ignored.