pub struct Options {
pub read_only: bool,
pub roll_metadata_key_byte_count: u64,
pub pre_commit_hook: PreCommitHook,
pub post_commit_hook: PostCommitHook,
pub skip_initial_reap: bool,
pub trim_config: Option<(Duration, Duration)>,
pub image_builder_mode: Option<SuperBlockInstance>,
pub inline_crypto_enabled: bool,
pub barriers_enabled: bool,
pub power_manager: Option<Arc<dyn PowerManager>>,
pub trim_charger_wait: Duration,
}Fields
read_only: boolTrue if the filesystem is read-only.
roll_metadata_key_byte_count: u64The metadata keys will be rolled after this many bytes. This must be large enough such that we can’t end up with more than two live keys (so it must be bigger than the maximum possible size of unflushed journal contents). This is exposed for testing purposes.
pre_commit_hook: PreCommitHookA callback that runs before every transaction is committed. If this callback returns an error then the transaction is failed with that error.
post_commit_hook: PostCommitHookA callback that runs after every transaction has been committed. This will be called whilst a lock is held which will block more transactions from being committed.
skip_initial_reap: boolIf true, don’t do an initial reap of the graveyard at mount time. This is useful for testing.
trim_config: Option<(Duration, Duration)>image_builder_mode: Option<SuperBlockInstance>inline_crypto_enabled: boolbarriers_enabled: boolpower_manager: Option<Arc<dyn PowerManager>>If set, this will be used to check for charger status before trimming.
trim_charger_wait: DurationHow long to wait after being placed on a charger before starting a trim.