pub struct AllocatedRanges { /* private fields */ }Expand description
AllocatedRanges tracks the logical ranges of a file which are pre-allocated using allocate, in other words, the ranges of the file with overwrite extents. It’s used by PagedObjectHandle to split writes to CoW ranges and writes to overwrite ranges into separate batches so they can have different transaction options.
Implementations
Sourceimpl AllocatedRanges
impl AllocatedRanges
pub fn empty() -> Self
pub fn new(ranges_to_apply: &[Range<u64>]) -> Self
pub fn clear(&mut self)
pub fn is_empty(&self) -> bool
Sourcepub fn overlap<'a>(&'a self, query_range: Range<u64>) -> RangeOverlapIter<'a>
pub fn overlap<'a>(&'a self, query_range: Range<u64>) -> RangeOverlapIter<'a>
Find the overlapping overwrite ranges in the given range for this file, so writes can be split between them appropriately. Ranges with RangeType::Overwrite should be written to with multi_overwrite and RangeType::Cow should use multi_write.
Sourcepub fn apply_range(&mut self, new_range: Range<u64>)
pub fn apply_range(&mut self, new_range: Range<u64>)
Apply range takes a single, valid file range and inserts it into the list of ranges it’s storing. This list of ranges, so it’s easy to insert and search, is kept sorted and merged, so that the list has no overlapping ranges.
pub fn apply_range_to(ranges: &mut Vec<Range<u64>>, new_range: Range<u64>)
Sourcepub fn truncate(&mut self, cutoff: u64) -> bool
pub fn truncate(&mut self, cutoff: u64) -> bool
For when a file is truncated. Drop any ranges past the cutoff point. If a range covers the cutoff point, it is modified to end at the cutoff.
Additionally, this returns true if there were previously tracked ranges but they were all completely removed by this truncate call. In this case, metadata for a file will need to be updated since there are no longer any overwrite ranges.