pub struct EncryptedMutationsV40 { /* private fields */ }Trait Implementations
Sourceimpl<'de> Deserialize<'de> for EncryptedMutationsV40
impl<'de> Deserialize<'de> for EncryptedMutationsV40
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<EncryptedMutationsV40> for EncryptedMutationsV49
impl From<EncryptedMutationsV40> for EncryptedMutationsV49
Sourcefn from(value: EncryptedMutationsV40) -> Self
fn from(value: EncryptedMutationsV40) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for EncryptedMutationsV40
impl Serialize for EncryptedMutationsV40
Sourceimpl TypeFingerprint for EncryptedMutationsV40
impl TypeFingerprint for EncryptedMutationsV40
fn fingerprint() -> String
Sourceimpl Versioned for EncryptedMutationsV40
impl Versioned for EncryptedMutationsV40
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>