pub struct EncryptedTransactionV57(pub Vec<Mutation>);Tuple Fields
0: Vec<Mutation>Trait Implementations
Sourceimpl Clone for EncryptedTransactionV57
impl Clone for EncryptedTransactionV57
Sourcefn clone(&self) -> EncryptedTransactionV57
fn clone(&self) -> EncryptedTransactionV57
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncryptedTransactionV57
impl Debug for EncryptedTransactionV57
Sourceimpl<'de> Deserialize<'de> for EncryptedTransactionV57
impl<'de> Deserialize<'de> for EncryptedTransactionV57
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EncryptedTransactionV57
Sourceimpl Ord for EncryptedTransactionV57
impl Ord for EncryptedTransactionV57
Sourcefn cmp(&self, other: &EncryptedTransactionV57) -> Ordering
fn cmp(&self, other: &EncryptedTransactionV57) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for EncryptedTransactionV57
impl PartialEq for EncryptedTransactionV57
Sourceimpl PartialOrd for EncryptedTransactionV57
impl PartialOrd for EncryptedTransactionV57
Sourceimpl Serialize for EncryptedTransactionV57
impl Serialize for EncryptedTransactionV57
impl StructuralPartialEq for EncryptedTransactionV57
Sourceimpl TypeFingerprint for EncryptedTransactionV57
impl TypeFingerprint for EncryptedTransactionV57
fn fingerprint() -> String
Sourceimpl Versioned for EncryptedTransactionV57
impl Versioned for EncryptedTransactionV57
Sourcefn max_serialized_size() -> Option<u64>
fn max_serialized_size() -> Option<u64>
Maximum size of a serialized version of this type. Serialization and deserialization will
fail if the limit is exceeded. If None, there is no limit. None is preferred over u64::MAX
because serializing and deserializing with a limit has runtime overhead.
fn deserialize_from<R>(reader: &mut R, _version: Version) -> Result<Self>
fn serialize_into<W>(&self, writer: &mut W) -> Result<()>
Sourceimpl VersionedLatest for EncryptedTransactionV57
impl VersionedLatest for EncryptedTransactionV57
Sourcefn deserialize_from_version<R>(reader: &mut R, version: Version) -> Result<Self>
fn deserialize_from_version<R>(reader: &mut R, version: Version) -> Result<Self>
Deserializes from a given version format and upgrades to the latest version.