pub trait HandleOwner:
AsRef<ObjectStore>
+ Send
+ Sync
+ 'static { }Expand description
DataObjectHandle stores an owner that must implement this trait, which allows the handle to get back to an ObjectStore.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".