pub struct Options<'a> {
pub skip_journal_checks: bool,
pub skip_key_roll: bool,
pub borrow_metadata_space: bool,
pub allocator_reservation: Option<&'a Reservation>,
}Expand description
This allows for special handling of certain transactions such as deletes and the
extension of Journal extents. For most other use cases it is appropriate to use
default() here.
Fields
skip_journal_checks: boolIf true, don’t check for low journal space. This should be true for any transactions that might alleviate journal space (i.e. compaction).
skip_key_roll: boolIf true, don’t check if we need to roll the mutations key.
borrow_metadata_space: boolIf true, borrow metadata space from the metadata reservation. This setting should be set to true for any transaction that will either not affect space usage after compaction (e.g. setting attributes), or reduce space usage (e.g. unlinking). Otherwise, a transaction might fail with an out-of-space error.
allocator_reservation: Option<&'a Reservation>If specified, a reservation to be used with the transaction. If not set, any allocations that are part of this transaction will have to take their chances, and will fail if there is no free space. The intention is that this should be used for things like the journal which require guaranteed space.