pub struct KeyDeserializer<'a> {
pub data: &'a [u8],
/* private fields */
}Expand description
Handles decoding of sequential serialized key payloads.
Fields
data: &'a [u8]Implementations
Sourceimpl<'a> KeyDeserializer<'a>
impl<'a> KeyDeserializer<'a>
Sourcepub fn new(data: &'a [u8], base: Option<u64>) -> Result<(Self, usize), Error>
pub fn new(data: &'a [u8], base: Option<u64>) -> Result<(Self, usize), Error>
Parses serialized key with a 2-byte length prefix from the front of payload data.
Sourcepub fn new_without_prefix(data: &'a [u8]) -> Self
pub fn new_without_prefix(data: &'a [u8]) -> Self
Constructs deserializer without expecting standard 2-byte size prefix.
Sourcepub fn read_u64(&mut self) -> Result<u64, Error>
pub fn read_u64(&mut self) -> Result<u64, Error>
Reads a u64. If a base was provided and this is the first u64, it applies the base.
Sourcepub fn read_varint(&mut self) -> Result<u64, Error>
pub fn read_varint(&mut self) -> Result<u64, Error>
Extracts an order-preserving decoded 64-bit variable length integer from stream.