KeySerializer

Struct KeySerializer 

pub struct KeySerializer<'a, B: Buffer> { /* private fields */ }
Serializes keys sequentially into binary format suitable for lexicographical comparisons.

The key layout contains:

  • A 2-byte Big-Endian length prefix specifying the size of the serialized data in bytes.
  • The encoded variable-length binary key payload.

Implementations

Source

impl<'a, B: Buffer> KeySerializer<'a, B>

pub fn new(buffer: &'a mut B, base: Option<u64>) -> Self

Creates a new KeySerializer attached to a persistent storage buffer.

pub fn write_u64(&mut self, v: u64)

Writes an order-preserving varint encoded 64-bit payload to buffer. If a base was provided and this is the first u64, it writes the delta.

pub fn write_bytes(&mut self, bytes: &[u8])

Writes fixed-length raw byte payloads into serialization buffer.

pub fn finalize(&mut self)

Resolves and writes the real key byte payload length to the two-byte prefix placeholder.

pub fn write_varint(&mut self, v: u64)

Writes an order-preserving varint encoded 64-bit payload to buffer.

pub fn write_last(&mut self, bytes: &[u8])

Writes trailing variable-length dynamic strings or vectors to serialization buffer.